@@ -1,4 +1,5 @@
-# Copyright 2012-2020 CERN for the benefit of the ATLAS collaboration.
+# -*- coding: utf-8 -*-
+# Copyright CERN since 2012
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -11,30 +12,11 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-#
-# Authors:
-# - Thomas Beermann <thomas.beermann@cern.ch>, 2012-2013
-# - Vincent Garonne <vgaronne@gmail.com>, 2012-2018
-# - Mario Lassnig <mario.lassnig@cern.ch>, 2012-2013
-# - Yun-Pin Sun <winter0128@gmail.com>, 2013
-# - Martin Barisits <martin.barisits@cern.ch>, 2013-2018
-# - Cedric Serfon <cedric.serfon@cern.ch>, 2014-2019
-# - Cheng-Hsi Chao <cheng-hsi.chao@cern.ch>, 2014
-# - Ralph Vigne <ralph.vigne@cern.ch>, 2015
-# - Joaquin Bogado <jbogado@linti.unlp.edu.ar>, 2015
-# - Hannes Hansen <hannes.jakob.hansen@cern.ch>, 2018-2019
-# - Andrew Lister <andrew.lister@stfc.ac.uk>, 2019
-# - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2020
-#
-# PY3K COMPATIBLE
-
-try:
-    from urllib import quote_plus
-except ImportError:
-    from urllib.parse import quote_plus
 
 from json import dumps
+
 from requests.status_codes import codes
+from six.moves.urllib.parse import quote_plus
 
 from rucio.client.baseclient import BaseClient
 from rucio.client.baseclient import choice
@@ -47,26 +29,23 @@ class AccountClient(BaseClient):
 
     ACCOUNTS_BASEURL = 'accounts'
 
-    def __init__(self, rucio_host=None, auth_host=None, account=None, ca_cert=None, auth_type=None, creds=None, timeout=600, user_agent='rucio-clients', vo=None):
-        super(AccountClient, self).__init__(rucio_host, auth_host, account, ca_cert, auth_type, creds, timeout, user_agent, vo=vo)
-
-    def add_account(self, account, type, email):
+    def add_account(self, account, type_, email):
         """
         Sends the request to create a new account.
 
         :param account: the name of the account.
-        :param type: The account type
+        :param type_: The account type
         :param email: The Email address associated with the account.
 
         :return: True if account was created successfully else False.
         :raises Duplicate: if account already exists.
         """
 
-        data = dumps({'type': type, 'email': email})
+        data = dumps({'type': type_, 'email': email})
         path = '/'.join([self.ACCOUNTS_BASEURL, account])
         url = build_url(choice(self.list_hosts), path=path)
 
-        res = self._send_request(url, type='POST', data=data)
+        res = self._send_request(url, type_='POST', data=data)
         if res.status_code == codes.created:
             return True
         exc_cls, exc_msg = self._get_exception(headers=res.headers, status_code=res.status_code, data=res.content)
@@ -84,7 +63,7 @@ class AccountClient(BaseClient):
         path = '/'.join([self.ACCOUNTS_BASEURL, account])
         url = build_url(choice(self.list_hosts), path=path)
 
-        res = self._send_request(url, type='DEL')
+        res = self._send_request(url, type_='DEL')
 
         if res.status_code == codes.ok:
             return True
@@ -121,7 +100,7 @@ class AccountClient(BaseClient):
         path = '/'.join([self.ACCOUNTS_BASEURL, account])
         url = build_url(choice(self.list_hosts), path=path)
 
-        res = self._send_request(url, type='PUT', data=data)
+        res = self._send_request(url, type_='PUT', data=data)
 
         if res.status_code == codes.ok:
             return True
@@ -186,7 +165,7 @@ class AccountClient(BaseClient):
 
         url = build_url(choice(self.list_hosts), path=path)
 
-        res = self._send_request(url, type='POST', data=data)
+        res = self._send_request(url, type_='POST', data=data)
 
         if res.status_code == codes.created:
             return True
@@ -209,7 +188,7 @@ class AccountClient(BaseClient):
 
         url = build_url(choice(self.list_hosts), path=path)
 
-        res = self._send_request(url, type='DEL', data=data)
+        res = self._send_request(url, type_='DEL', data=data)
 
         if res.status_code == codes.ok:
             return True
@@ -242,7 +221,7 @@ class AccountClient(BaseClient):
 
         path = '/'.join([self.ACCOUNTS_BASEURL, account, 'rules'])
         url = build_url(choice(self.list_hosts), path=path)
-        res = self._send_request(url, type='GET')
+        res = self._send_request(url, type_='GET')
         if res.status_code == codes.ok:
             return self._load_json_data(res)
         else:
@@ -276,7 +255,7 @@ class AccountClient(BaseClient):
 
         path = '/'.join([self.ACCOUNTS_BASEURL, account, 'limits', 'global', quote_plus(rse_expression)])
         url = build_url(choice(self.list_hosts), path=path)
-        res = self._send_request(url, type='GET')
+        res = self._send_request(url, type_='GET')
         if res.status_code == codes.ok:
             return next(self._load_json_data(res))
         exc_cls, exc_msg = self._get_exception(headers=res.headers, status_code=res.status_code, data=res.content)
@@ -291,7 +270,7 @@ class AccountClient(BaseClient):
 
         path = '/'.join([self.ACCOUNTS_BASEURL, account, 'limits', 'global'])
         url = build_url(choice(self.list_hosts), path=path)
-        res = self._send_request(url, type='GET')
+        res = self._send_request(url, type_='GET')
         if res.status_code == codes.ok:
             return next(self._load_json_data(res))
         exc_cls, exc_msg = self._get_exception(headers=res.headers, status_code=res.status_code, data=res.content)
@@ -306,7 +285,7 @@ class AccountClient(BaseClient):
 
         path = '/'.join([self.ACCOUNTS_BASEURL, account, 'limits', 'local'])
         url = build_url(choice(self.list_hosts), path=path)
-        res = self._send_request(url, type='GET')
+        res = self._send_request(url, type_='GET')
         if res.status_code == codes.ok:
             return next(self._load_json_data(res))
         exc_cls, exc_msg = self._get_exception(headers=res.headers, status_code=res.status_code, data=res.content)
@@ -322,7 +301,7 @@ class AccountClient(BaseClient):
 
         path = '/'.join([self.ACCOUNTS_BASEURL, account, 'limits', 'local', rse])
         url = build_url(choice(self.list_hosts), path=path)
-        res = self._send_request(url, type='GET')
+        res = self._send_request(url, type_='GET')
         if res.status_code == codes.ok:
             return next(self._load_json_data(res))
         exc_cls, exc_msg = self._get_exception(headers=res.headers, status_code=res.status_code, data=res.content)
@@ -340,7 +319,7 @@ class AccountClient(BaseClient):
         else:
             path = '/'.join([self.ACCOUNTS_BASEURL, account, 'usage', 'local'])
         url = build_url(choice(self.list_hosts), path=path)
-        res = self._send_request(url, type='GET')
+        res = self._send_request(url, type_='GET')
         if res.status_code == codes.ok:
             return self._load_json_data(res)
         else:
@@ -359,7 +338,7 @@ class AccountClient(BaseClient):
         else:
             path = '/'.join([self.ACCOUNTS_BASEURL, account, 'usage', 'global'])
         url = build_url(choice(self.list_hosts), path=path)
-        res = self._send_request(url, type='GET')
+        res = self._send_request(url, type_='GET')
         if res.status_code == codes.ok:
             return self._load_json_data(res)
         else:
@@ -375,7 +354,7 @@ class AccountClient(BaseClient):
         """
         path = '/'.join([self.ACCOUNTS_BASEURL, account, 'usage/history', rse])
         url = build_url(choice(self.list_hosts), path=path)
-        res = self._send_request(url, type='GET')
+        res = self._send_request(url, type_='GET')
         if res.status_code == codes.ok:
             return next(self._load_json_data(res))
         else:
@@ -390,7 +369,7 @@ class AccountClient(BaseClient):
         """
         path = '/'.join([self.ACCOUNTS_BASEURL, account, 'attr/'])
         url = build_url(choice(self.list_hosts), path=path)
-        res = self._send_request(url, type='GET')
+        res = self._send_request(url, type_='GET')
         if res.status_code == codes.ok:
             return self._load_json_data(res)
         else:
@@ -409,7 +388,7 @@ class AccountClient(BaseClient):
         data = dumps({'key': key, 'value': value})
         path = '/'.join([self.ACCOUNTS_BASEURL, account, 'attr', key])
         url = build_url(choice(self.list_hosts), path=path)
-        res = self._send_request(url, type='POST', data=data)
+        res = self._send_request(url, type_='POST', data=data)
         if res.status_code == codes.created:
             return True
         else:
@@ -426,7 +405,7 @@ class AccountClient(BaseClient):
 
         path = '/'.join([self.ACCOUNTS_BASEURL, account, 'attr', key])
         url = build_url(choice(self.list_hosts), path=path)
-        res = self._send_request(url, type='DEL', data=None)
+        res = self._send_request(url, type_='DEL', data=None)
         if res.status_code == codes.ok:
             return True
         else:
