@@ -1,4 +1,5 @@
-# Copyright 2014-2018 CERN for the benefit of the ATLAS collaboration.
+# -*- coding: utf-8 -*-
+# Copyright CERN since 2014
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -11,24 +12,11 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-#
-# Authors:
-# - Martin Barisits <martin.barisits@cern.ch>, 2014-2020
-# - Cedric Serfon <cedric.serfon@cern.ch>, 2014
-# - Vincent Garonne <vgaronne@gmail.com>, 2014-2018
-# - Ralph Vigne <ralph.vigne@cern.ch>, 2015
-# - Hannes Hansen <hannes.jakob.hansen@cern.ch>, 2019
-# - Andrew Lister <andrew.lister@stfc.ac.uk>, 2019
-#
-# PY3K COMPATIBLE
-
-try:
-    from urllib import quote_plus
-except ImportError:
-    from urllib.parse import quote_plus
 
 from json import dumps
+
 from requests.status_codes import codes
+from six.moves.urllib.parse import quote_plus
 
 from rucio.client.baseclient import BaseClient
 from rucio.client.baseclient import choice
@@ -41,26 +29,21 @@ class AccountLimitClient(BaseClient):
 
     ACCOUNTLIMIT_BASEURL = 'accountlimits'
 
-    def __init__(self, rucio_host=None, auth_host=None, account=None, ca_cert=None,
-                 auth_type=None, creds=None, timeout=600, user_agent='rucio-clients', vo=None):
-        super(AccountLimitClient, self).__init__(rucio_host, auth_host, account, ca_cert,
-                                                 auth_type, creds, timeout, user_agent, vo=vo)
-
-    def set_account_limit(self, account, rse, bytes, locality):
+    def set_account_limit(self, account, rse, bytes_, locality):
         """
         Sets an account limit for a given limit scope.
 
         :param account: The name of the account.
         :param rse:     The rse name.
-        :param bytes:   An integer with the limit in bytes.
+        :param bytes_:   An integer with the limit in bytes.
         :param locality: The scope of the account limit. 'local' or 'global'.
         :return:        True if quota was created successfully else False.
         """
 
         if locality == 'local':
-            return self.set_local_account_limit(account, rse, bytes)
+            return self.set_local_account_limit(account, rse, bytes_)
         elif locality == 'global':
-            return self.set_global_account_limit(account, rse, bytes)
+            return self.set_global_account_limit(account, rse, bytes_)
         else:
             from rucio.common.exception import UnsupportedOperation
             raise UnsupportedOperation('The provided scope (%s) for the account limit was invalid' % locality)
@@ -83,21 +66,21 @@ class AccountLimitClient(BaseClient):
             from rucio.common.exception import UnsupportedOperation
             raise UnsupportedOperation('The provided scope (%s) for the account limit was invalid' % locality)
 
-    def set_local_account_limit(self, account, rse, bytes):
+    def set_local_account_limit(self, account, rse, bytes_):
         """
         Sends the request to set an account limit for an account.
 
         :param account: The name of the account.
         :param rse:     The rse name.
-        :param bytes:   An integer with the limit in bytes.
+        :param bytes_:   An integer with the limit in bytes.
         :return:        True if quota was created successfully else False.
         """
 
-        data = dumps({'bytes': bytes})
+        data = dumps({'bytes': bytes_})
         path = '/'.join([self.ACCOUNTLIMIT_BASEURL, 'local', account, rse])
         url = build_url(choice(self.list_hosts), path=path)
 
-        r = self._send_request(url, type='POST', data=data)
+        r = self._send_request(url, type_='POST', data=data)
 
         if r.status_code == codes.created:
             return True
@@ -119,7 +102,7 @@ class AccountLimitClient(BaseClient):
         path = '/'.join([self.ACCOUNTLIMIT_BASEURL, 'local', account, rse])
         url = build_url(choice(self.list_hosts), path=path)
 
-        r = self._send_request(url, type='DEL')
+        r = self._send_request(url, type_='DEL')
 
         if r.status_code == codes.ok:
             return True
@@ -127,21 +110,21 @@ class AccountLimitClient(BaseClient):
             exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
             raise exc_cls(exc_msg)
 
-    def set_global_account_limit(self, account, rse_expression, bytes):
+    def set_global_account_limit(self, account, rse_expression, bytes_):
         """
         Sends the request to set a global account limit for an account.
 
         :param account:        The name of the account.
         :param rse_expression: The rse expression.
-        :param bytes:          An integer with the limit in bytes.
+        :param bytes_:          An integer with the limit in bytes.
         :return:               True if quota was created successfully else False.
         """
 
-        data = dumps({'bytes': bytes})
+        data = dumps({'bytes': bytes_})
         path = '/'.join([self.ACCOUNTLIMIT_BASEURL, 'global', account, quote_plus(rse_expression)])
         url = build_url(choice(self.list_hosts), path=path)
 
-        r = self._send_request(url, type='POST', data=data)
+        r = self._send_request(url, type_='POST', data=data)
 
         if r.status_code == codes.created:
             return True
@@ -163,7 +146,7 @@ class AccountLimitClient(BaseClient):
         path = '/'.join([self.ACCOUNTLIMIT_BASEURL, 'global', account, quote_plus(rse_expression)])
         url = build_url(choice(self.list_hosts), path=path)
 
-        r = self._send_request(url, type='DEL')
+        r = self._send_request(url, type_='DEL')
 
         if r.status_code == codes.ok:
             return True
