@@ -1,4 +1,5 @@
-# Copyright 2014-2018 CERN for the benefit of the ATLAS collaboration.
+# -*- coding: utf-8 -*-
+# Copyright CERN since 2014
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -11,18 +12,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-#
-# Authors:
-# - Mario Lassnig <mario.lassnig@cern.ch>, 2014
-# - Cedric Serfon <cedric.serfon@cern.ch>, 2014
-# - Vincent Garonne <vgaronne@gmail.com>, 2014-2018
-# - Ralph Vigne <ralph.vigne@cern.ch>, 2015
-# - Martin Barisits <martin.barisits@cern.ch>, 2018
-# - Hannes Hansen <hannes.jakob.hansen@cern.ch>, 2019
-# - Andrew Lister <andrew.lister@stfc.ac.uk>, 2019
-# - Radu Carpa <radu.carpa@cern.ch>, 2021
-#
-# PY3K COMPATIBLE
 
 from json import dumps
 
@@ -44,9 +33,6 @@ class ConfigClient(BaseClient):
 
     CONFIG_BASEURL = 'config'
 
-    def __init__(self, rucio_host=None, auth_host=None, account=None, ca_cert=None, auth_type=None, creds=None, timeout=600, user_agent='rucio-clients', vo=None):
-        super(ConfigClient, self).__init__(rucio_host, auth_host, account, ca_cert, auth_type, creds, timeout, user_agent, vo=vo)
-
     def get_config(self, section=None, option=None):
         """
         Sends the request to get the matching configuration.
@@ -67,7 +53,7 @@ class ConfigClient(BaseClient):
 
         url = build_url(choice(self.list_hosts), path=path)
 
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             return r.json()
         else:
@@ -99,11 +85,11 @@ class ConfigClient(BaseClient):
                     option: value
                 }
             })
-            r = self._send_request(url, type='POST', data=data)
+            r = self._send_request(url, type_='POST', data=data)
         else:
             path = '/'.join([self.CONFIG_BASEURL, section, option, value])
             url = build_url(choice(self.list_hosts), path=path)
-            r = self._send_request(url, type='PUT')
+            r = self._send_request(url, type_='PUT')
 
         if r.status_code == codes.created:
             return True
@@ -123,7 +109,7 @@ class ConfigClient(BaseClient):
         path = '/'.join([self.CONFIG_BASEURL, section, option])
         url = build_url(choice(self.list_hosts), path=path)
 
-        r = self._send_request(url, type='DEL')
+        r = self._send_request(url, type_='DEL')
 
         if r.status_code == codes.ok:
             return True
