@@ -1,4 +1,5 @@
-# Copyright 2013-2020 CERN for the benefit of the ATLAS collaboration.
+# -*- coding: utf-8 -*-
+# Copyright CERN since 2013
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -11,16 +12,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-#
-# Authors:
-# - Vincent Garonne <vincent.garonne@cern.ch>, 2013-2018
-# - Martin Barisits <martin.barisits@cern.ch>, 2013-2019
-# - Cedric Serfon <cedric.serfon@cern.ch>, 2013-2015
-# - WeiJen Chang <e4523744@gmail.com>, 2014
-# - Mario Lassnig <mario.lassnig@cern.ch>, 2014
-# - Ralph Vigne <ralph.vigne@cern.ch>, 2015
-# - Joaquin Bogado <jbogado@linti.unlp.edu.ar>, 2018
-# - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2020
 
 '''
 Compatibility Wrapper for DQ2 and Rucio.
@@ -98,13 +89,13 @@ class DQ2Client:
         result['dn'] = None
         if len(account) < 30:
             result['nickname'] = nickname
-            for id in self.client.list_identities(account):
-                if id['type'] == 'GSS':
-                    result['email'] = id['identity']
-                elif id['type'] == 'X509':
+            for id_ in self.client.list_identities(account):
+                if id_['type'] == 'GSS':
+                    result['email'] = id_['identity']
+                elif id_['type'] == 'X509':
                     if not result['dn']:
                         result['dn'] = []
-                    result['dn'].append(id['identity'])
+                    result['dn'].append(id_['identity'])
         else:
             result['dn'] = userId
             nicknames, emails = [], []
@@ -180,7 +171,7 @@ class DQ2Client:
         """
         raise NotImplementedError
 
-    def deleteDatasetReplicas(self, dsn, locations, version=0, force=False, deep=False, logical=False, ignore_lifetime=False, all=False, grace_period=None, ignore_pin=False, scope=None):
+    def deleteDatasetReplicas(self, dsn, locations, version=0, force=False, deep=False, logical=False, ignore_lifetime=False, all_=False, grace_period=None, ignore_pin=False, scope=None):
         """
         Delete the dataset replica from the given site.
 
@@ -484,11 +475,11 @@ class DQ2Client:
         vuid = '%s-%s-%s-%s-%s' % (vuid[0:8], vuid[8:12], vuid[12:16], vuid[16:20], vuid[20:32])
         duid = vuid
         nbfiles = 0
-        bytes = 0
+        bytes_ = 0
         for f in self.client.list_files(scope=scope, name=dsn):
             nbfiles += 1
-            bytes += f['bytes']
-        return (duid, vuid, 1, metadata['created_at'], '', '', nbfiles, bytes)
+            bytes_ += f['bytes']
+        return (duid, vuid, 1, metadata['created_at'], '', '', nbfiles, bytes_)
 
     def listDatasetReplicas(self, dsn, version=0, complete=None, old=True, scope=None):
         """
@@ -707,7 +698,7 @@ class DQ2Client:
                 dataset = dataset[:-1]
                 collection = 'container'
             filters = {'name': dataset}
-            for name in self.client.list_dids(scope, filters, type=collection):
+            for name in self.client.list_dids(scope, filters, did_type=collection):
                 vuid = hashlib.md5(scope + ':' + name).hexdigest()
                 vuid = '%s-%s-%s-%s-%s' % (vuid[0:8], vuid[8:12], vuid[12:16], vuid[16:20], vuid[20:32])
                 duid = vuid
@@ -717,7 +708,7 @@ class DQ2Client:
         else:
             raise InputValidationError
 
-    def listDatasets2(self, metaDataAttributes, long=False, all=False, p=None, rpp=None, scope=None):
+    def listDatasets2(self, metaDataAttributes, long=False, all_=False, p=None, rpp=None, scope=None):
         """
         ToDo -> Jingya You
 
@@ -731,7 +722,7 @@ class DQ2Client:
 
         @param metaDataAttributes: metadata attibutes for the sorting
         @param long: List dataset in long format (total sum for all the file sizes + total num of files).
-        @param all: List all datasets, including the hidden ones.
+        @param all_: List all datasets, including the hidden ones.
         @param rpp: Print rrp first results.
         @param p: Specify page to print.
 
@@ -751,7 +742,7 @@ class DQ2Client:
         filters = {}
         if (scope is None) and 'name' in metaDataAttributes:
             scope, dsn = extract_scope(metaDataAttributes['name'])
-            type = 'collection'
+            type_ = 'collection'
             metadata = ['state', 'type', 'name']
             for key in metaDataAttributes:
                 if key not in metadata:
@@ -765,11 +756,11 @@ class DQ2Client:
                         filters['is_open'] = 0
                 elif key == 'type':
                     if metaDataAttributes[key] == 1:
-                        type = 'dataset'
+                        type_ = 'dataset'
                     elif metaDataAttributes[key] == 2:
-                        type = 'container'
+                        type_ = 'container'
             if long:
-                for name in self.client.list_dids(scope, filters, type):
+                for name in self.client.list_dids(scope, filters, type_):
                     meta = {'totalSize': 0, 'totalFiles': 0}
                     # Can take very long. Bulk method is needed !!!
                     for did in self.client.list_files(scope=scope, name=name):
@@ -777,7 +768,7 @@ class DQ2Client:
                         meta['totalFiles'] += 1
                     result['%s:%s' % (scope, name)] = meta
             else:
-                if type == 'collection':
+                if type_ == 'collection':
                     for name in self.client.list_dids(scope, filters, 'dataset'):
                         result['%s:%s' % (scope, name)] = {}
                     if filters['name'].endswith('/'):
@@ -785,10 +776,10 @@ class DQ2Client:
                     for name in self.client.list_dids(scope, filters, 'container'):
                         result['%s:%s/' % (scope, name)] = {}
                 else:
-                    for name in self.client.list_dids(scope, filters, type):
-                        if type == 'container':
+                    for name in self.client.list_dids(scope, filters, type_):
+                        if type_ == 'container':
                             result['%s:%s/' % (scope, name)] = {}
-                        elif type == 'datasets':
+                        elif type_ == 'datasets':
                             result['%s:%s' % (scope, name)] = {}
             return result
         else:
@@ -822,7 +813,7 @@ class DQ2Client:
             result[guid] = datasets
         return result
 
-    def listDatasetsByMetaData(self, filter):
+    def listDatasetsByMetaData(self, filter_):
         """
         List the dataset versions that match the given criteria.
         In DQ2 the autorized metadata are :
@@ -831,7 +822,7 @@ class DQ2Client:
         In Rucio the authorized metadata are :
         state, type, name
 
-        @param filter: list containing dictionaries of metadata attributes and values
+        @param filter_: list containing dictionaries of metadata attributes and values
             ({'attrname_0': attrvalue_0, ..., 'attrname_N': attrvalue_N}).
 
         B{Exceptions:}
@@ -845,7 +836,7 @@ class DQ2Client:
             ]
         """
         metadata = ['state', 'type', 'name']
-        for key in filter:
+        for key in filter_:
             if key not in metadata:
                 raise InvalidMetadata
         raise NotImplementedError
@@ -1155,8 +1146,8 @@ class DQ2Client:
             if rule['state'] != 'OK' and (location == rule['rse_expression']):  # or location in [i['rse'] for i in self.client.list_rses(rule['rse_expression'])]):
                 print(rule)
                 if rule['created_at'] < creationdate:
-                    id = rule['id']
-                    id = '%s-%s-%s-%s-%s' % (id[0:8], id[8:12], id[12:16], id[16:20], id[20:32])
+                    id_ = rule['id']
+                    id_ = '%s-%s-%s-%s-%s' % (id_[0:8], id_[8:12], id_[12:16], id_[16:20], id_[20:32])
                     owner = rule['account']
                     destination = None
                     creationdate = rule['created_at']
@@ -1180,7 +1171,7 @@ class DQ2Client:
                     parentId = 'None'
                     requestId = hashlib.md5('%s:%s:%s' % (scope, dsn, location)).hexdigest()
                     requestId = '%s-%s-%s-%s-%s' % (requestId[0:8], requestId[8:12], requestId[12:16], requestId[16:20], requestId[20:32])
-                    result = (id, owner, location, destination, creationdate, modifieddate, callbacks, archived, sources_policy, wait_for_sources, sources, query_more_sources, share, group, replica_lifetime, activity, parentId, requestId)
+                    result = (id_, owner, location, destination, creationdate, modifieddate, callbacks, archived, sources_policy, wait_for_sources, sources, query_more_sources, share, group, replica_lifetime, activity, parentId, requestId)
             elif rule['state'] == 'OK' and (location == rule['rse_expression']):  # or location in [i['rse'] for i in self.client.list_rses(rule['rse_expression'])]):
                 return ()
         return result
@@ -1585,7 +1576,7 @@ class DQ2Client:
                     guid = '%s-%s-%s-%s-%s' % (guid[0:8], guid[8:12], guid[12:16], guid[16:20], guid[20:32])
                     if guid != did['meta']['guid']:
                         result[lfn] = {'status': False, 'error': FileConsistencyMismatch('guid mismatch DDM %s vs user %s' % (guid, did['meta']['guid']))}
-                    elif meta['adler32'] != did['adler32']:
+                    elif str(meta['adler32']).lstrip('0') != str(did['adler32']).lstrip('0'):
                         result[lfn] = {'status': False, 'error': FileConsistencyMismatch('adler32 mismatch DDM %s vs user %s' % (meta['adler32'], did['adler32']))}
                     elif meta['bytes'] != did['bytes']:
                         result[lfn] = {'status': False, 'error': FileConsistencyMismatch('filesize mismatch DDM %s vs user %s' % (meta['bytes'], did['bytes']))}
