@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2013-2021 CERN
+# Copyright CERN since 2013
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,22 +12,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-#
-# Authors:
-# - Vincent Garonne <vincent.garonne@cern.ch>, 2013-2018
-# - Mario Lassnig <mario.lassnig@cern.ch>, 2013-2021
-# - Cedric Serfon <cedric.serfon@cern.ch>, 2014-2018
-# - Ralph Vigne <ralph.vigne@cern.ch>, 2015
-# - Brian Bockelman <bbockelm@cse.unl.edu>, 2018
-# - Martin Barisits <martin.barisits@cern.ch>, 2018-2021
-# - Hannes Hansen <hannes.jakob.hansen@cern.ch>, 2018-2019
-# - Jaroslav Guenther <jaroslav.guenther@cern.ch>, 2019
-# - Ilija Vukotic <ivukotic@cern.ch>, 2020
-# - Luc Goossens <luc.goossens@cern.ch>, 2020
-# - Andrew Lister <andrew.lister@stfc.ac.uk>, 2019
-# - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2020-2021
-# - Eric Vaandering <ewv@fnal.gov>, 2020
-# - Radu Carpa <radu.carpa@cern.ch>, 2021
 
 from datetime import datetime
 from json import dumps, loads
@@ -49,7 +33,7 @@ class ReplicaClient(BaseClient):
         """
         Declare a list of bad replicas.
 
-        :param pfns: The list of PFNs.
+        :param pfns: Either a list of PFNs (string) or a list of replicas {'scope': <scope>, 'name': <name>, 'rse_id': <rse_id>}.
         :param reason: The reason of the loss.
         """
         data = {'reason': reason, 'pfns': pfns}
