@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2012-2021 CERN
+# Copyright CERN since 2012
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,25 +12,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-#
-# Authors:
-# - Vincent Garonne <vincent.garonne@cern.ch>, 2012-2018
-# - Thomas Beermann <thomas.beermann@cern.ch>, 2012
-# - Mario Lassnig <mario.lassnig@cern.ch>, 2012-2020
-# - Ralph Vigne <ralph.vigne@cern.ch>, 2013-2015
-# - Martin Barisits <martin.barisits@cern.ch>, 2013-2018
-# - Cedric Serfon <cedric.serfon@cern.ch>, 2014
-# - Wen Guan <wen.guan@cern.ch>, 2014
-# - Brian Bockelman <bbockelm@cse.unl.edu>, 2018
-# - Joaquín Bogado <jbogado@linti.unlp.edu.ar>, 2018
-# - Hannes Hansen <hannes.jakob.hansen@cern.ch>, 2018
-# - Dimitrios Christidis <dimitrios.christidis@cern.ch>, 2018
-# - Andrew Lister <andrew.lister@stfc.ac.uk>, 2019
-# - Tomas Javurek <tomas.javurek@cern.ch>, 2020
-# - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2021
-# - David Población Criado <david.poblacion.criado@cern.ch>, 2021
-# - Radu Carpa <radu.carpa@cern.ch>, 2021
-# - Joel Dierkes <joel.dierkes@cern.ch>, 2021
 
 from json import dumps, loads
 
@@ -47,11 +28,6 @@ class RSEClient(BaseClient):
 
     RSE_BASEURL = 'rses'
 
-    def __init__(self, rucio_host=None, auth_host=None, account=None, ca_cert=None,
-                 auth_type=None, creds=None, timeout=600, user_agent='rucio-clients', vo=None):
-        super(RSEClient, self).__init__(rucio_host, auth_host, account, ca_cert,
-                                        auth_type, creds, timeout, user_agent, vo=vo)
-
     def get_rse(self, rse):
         """
         Returns details about the referred RSE.
@@ -65,7 +41,7 @@ class RSEClient(BaseClient):
         path = '/'.join([self.RSE_BASEURL, rse])
         url = build_url(choice(self.list_hosts), path=path)
 
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             rse = loads(r.text)
             return rse
@@ -98,7 +74,7 @@ class RSEClient(BaseClient):
         """
         path = 'rses/' + rse
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='POST', data=dumps(kwargs))
+        r = self._send_request(url, type_='POST', data=dumps(kwargs))
         if r.status_code == codes.created:
             return True
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
@@ -113,7 +89,7 @@ class RSEClient(BaseClient):
         """
         path = 'rses/' + rse
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='PUT', data=dumps(parameters))
+        r = self._send_request(url, type_='PUT', data=dumps(parameters))
         if r.status_code == codes.created:
             return True
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
@@ -128,7 +104,7 @@ class RSEClient(BaseClient):
         """
         path = 'rses/' + rse
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='DEL')
+        r = self._send_request(url, type_='DEL')
         if r.status_code == codes.ok:
             return True
         else:
@@ -148,7 +124,7 @@ class RSEClient(BaseClient):
         else:
             path = 'rses/'
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             return self._load_json_data(r)
         else:
@@ -170,7 +146,7 @@ class RSEClient(BaseClient):
         url = build_url(choice(self.list_hosts), path=path)
         data = dumps({'value': value})
 
-        r = self._send_request(url, type='POST', data=data)
+        r = self._send_request(url, type_='POST', data=data)
         if r.status_code == codes.created:
             return True
         else:
@@ -189,7 +165,7 @@ class RSEClient(BaseClient):
         path = '/'.join([self.RSE_BASEURL, rse, 'attr', key])
         url = build_url(choice(self.list_hosts), path=path)
 
-        r = self._send_request(url, type='DEL')
+        r = self._send_request(url, type_='DEL')
         if r.status_code == codes.ok:
             return True
         else:
@@ -206,7 +182,7 @@ class RSEClient(BaseClient):
         """
         path = '/'.join([self.RSE_BASEURL, rse, 'attr/'])
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             attributes = loads(r.text)
             return attributes
@@ -242,7 +218,7 @@ class RSEClient(BaseClient):
         scheme = params['scheme']
         path = '/'.join([self.RSE_BASEURL, rse, 'protocols', scheme])
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='POST', data=dumps(params))
+        r = self._send_request(url, type_='POST', data=dumps(params))
         if r.status_code == codes.created:
             return True
         else:
@@ -282,7 +258,7 @@ class RSEClient(BaseClient):
         params['protocol_domain'] = protocol_domain
         url = build_url(choice(self.list_hosts), path=path, params=params)
 
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             protocols = loads(r.text)
             return protocols
@@ -321,7 +297,7 @@ class RSEClient(BaseClient):
 
         url = build_url(choice(self.list_hosts), path=path, params=params, doseq=True)
 
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             pfns = loads(r.text)
             return pfns
@@ -353,7 +329,7 @@ class RSEClient(BaseClient):
 
         path = '/'.join(path)
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='DEL')
+        r = self._send_request(url, type_='DEL')
         if r.status_code == codes.ok:
             return True
         else:
@@ -387,7 +363,7 @@ class RSEClient(BaseClient):
 
         path = '/'.join(path)
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='PUT', data=dumps(data))
+        r = self._send_request(url, type_='PUT', data=dumps(data))
         if r.status_code == codes.ok:
             return True
         else:
@@ -441,7 +417,7 @@ class RSEClient(BaseClient):
         path = [self.RSE_BASEURL, rse, 'qos_policy', qos_policy]
         path = '/'.join(path)
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='POST')
+        r = self._send_request(url, type_='POST')
         if r.status_code == codes.created:
             return True
         else:
@@ -462,7 +438,7 @@ class RSEClient(BaseClient):
         path = [self.RSE_BASEURL, rse, 'qos_policy', qos_policy]
         path = '/'.join(path)
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='DEL')
+        r = self._send_request(url, type_='DEL')
         if r.status_code == codes.ok:
             return True
         else:
@@ -482,7 +458,7 @@ class RSEClient(BaseClient):
         path = [self.RSE_BASEURL, rse, 'qos_policy']
         path = '/'.join(path)
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             return loads(r.text)
         else:
@@ -505,7 +481,7 @@ class RSEClient(BaseClient):
         path = '/'.join(path)
         url = build_url(choice(self.list_hosts), path=path)
         data = {'source': source, 'used': used, 'free': free, 'files': files}
-        r = self._send_request(url, type='PUT', data=dumps(data))
+        r = self._send_request(url, type_='PUT', data=dumps(data))
         if r.status_code == codes.ok:
             return True
         else:
@@ -524,7 +500,7 @@ class RSEClient(BaseClient):
         path = [self.RSE_BASEURL, rse, 'usage']
         path = '/'.join(path)
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='GET', params=filters)
+        r = self._send_request(url, type_='GET', params=filters)
         if r.status_code == codes.ok:
             return self._load_json_data(r)
         else:
@@ -543,7 +519,7 @@ class RSEClient(BaseClient):
         path = [self.RSE_BASEURL, rse, 'usage', 'history']
         path = '/'.join(path)
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='GET', params=filters)
+        r = self._send_request(url, type_='GET', params=filters)
         if r.status_code == codes.ok:
             return self._load_json_data(r)
         else:
@@ -565,7 +541,7 @@ class RSEClient(BaseClient):
         path = [self.RSE_BASEURL, rse, 'limits']
         path = '/'.join(path)
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='PUT', data=dumps({'name': name, 'value': value}))
+        r = self._send_request(url, type_='PUT', data=dumps({'name': name, 'value': value}))
         if r.status_code == codes.ok:
             return True
         exc_cls, exc_msg = self._get_exception(headers=r.headers,
@@ -584,7 +560,7 @@ class RSEClient(BaseClient):
         path = [self.RSE_BASEURL, rse, 'limits']
         path = '/'.join(path)
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             return next(self._load_json_data(r))
         exc_cls, exc_msg = self._get_exception(headers=r.headers,
@@ -604,7 +580,7 @@ class RSEClient(BaseClient):
         path = [self.RSE_BASEURL, rse, 'limits']
         path = '/'.join(path)
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='DEL', data=dumps({'name': name}))
+        r = self._send_request(url, type_='DEL', data=dumps({'name': name}))
         if r.status_code == codes.ok:
             return True
         exc_cls, exc_msg = self._get_exception(headers=r.headers,
@@ -624,7 +600,7 @@ class RSEClient(BaseClient):
         path = [self.RSE_BASEURL, source, 'distances', destination]
         path = '/'.join(path)
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='POST', data=dumps(parameters))
+        r = self._send_request(url, type_='POST', data=dumps(parameters))
         if r.status_code == codes.created:
             return True
         exc_cls, exc_msg = self._get_exception(headers=r.headers,
@@ -643,7 +619,7 @@ class RSEClient(BaseClient):
         path = [self.RSE_BASEURL, source, 'distances', destination]
         path = '/'.join(path)
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='PUT', data=dumps(parameters))
+        r = self._send_request(url, type_='PUT', data=dumps(parameters))
         if r.status_code == codes.ok:
             return True
         exc_cls, exc_msg = self._get_exception(headers=r.headers,
@@ -663,7 +639,7 @@ class RSEClient(BaseClient):
         path = [self.RSE_BASEURL, source, 'distances', destination]
         path = '/'.join(path)
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             return next(self._load_json_data(r))
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
@@ -679,7 +655,7 @@ class RSEClient(BaseClient):
         path = [self.RSE_BASEURL, source, 'distances', destination]
         path = '/'.join(path)
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='DEL')
+        r = self._send_request(url, type_='DEL')
         if r.status_code == codes.ok:
             return True
         exc_cls, exc_msg = self._get_exception(headers=r.headers,
