@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2017-2021 CERN
+# Copyright CERN since 2013
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,26 +12,11 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-#
-# Authors:
-# - Vincent Garonne <vincent.garonne@cern.ch>, 2017
-# - Eric Vaandering <ewv@fnal.gov>, 2018-2021
-# - sartiran <root@polgrid107.in2p3.fr>, 2018
-# - Hannes Hansen <hannes.jakob.hansen@cern.ch>, 2018-2019
-# - Sartirana Andrea <sartiran@llr.in2p3.fr>, 2018
-# - Martin Barisits <martin.barisits@cern.ch>, 2019-2021
-# - Mario Lassnig <mario.lassnig@cern.ch>, 2019-2021
-# - Jaroslav Guenther <jaroslav.guenther@cern.ch>, 2020
-# - Andrew Lister <andrew.lister@stfc.ac.uk>, 2019
-# - Eli Chadwick <eli.chadwick@stfc.ac.uk>, 2020
-# - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2020
-# - Radu Carpa <radu.carpa@cern.ch>, 2021
 
 from jsonschema import validate, ValidationError
 
 from rucio.common.exception import InvalidObject
 
-
 ACCOUNT_LENGTH = 25
 
 ACCOUNT = {"description": "Account name",
@@ -96,6 +81,9 @@ ASK_APPROVAL = {"description": "Rule approval request",
 ASYNCHRONOUS = {"description": "Asynchronous rule creation",
                 "type": ["boolean", "null"]}
 
+DELAY_INJECTION = {"description": "Time (in seconds) to wait before starting applying the rule. Implies asynchronous rule creation.",
+                   "type": ["integer", "null"]}
+
 PURGE_REPLICAS = {"description": "Rule purge replica status",
                   "type": "boolean"}
 
@@ -204,6 +192,7 @@ RULE = {"description": "Replication rule",
                        "comment": COMMENT,
                        "ask_approval": ASK_APPROVAL,
                        "asynchronous": ASYNCHRONOUS,
+                       "delay_injection": DELAY_INJECTION,
                        "priority": PRIORITY,
                        'split_container': SPLIT_CONTAINER,
                        'meta': METADATA},
@@ -271,10 +260,8 @@ DID = {"description": "Data Identifier(DID)",
        "required": ["scope", "name", "type"],
        "additionalProperties": False}
 
-DID_FILTERS = {"description": "Filters dictionary to list DIDs",
-               "type": "object",
-               "properties": {"created_before": DATE,
-                              "created_afted": DATE},
+DID_FILTERS = {"description": "Array to filter DIDs by metadata",
+               "type": "array",
                "additionalProperties": True}
 
 R_DID = {"description": "Data Identifier(DID)",
