@@ -1,21 +1,17 @@
-'''
- Copyright European Organization for Nuclear Research (CERN)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- You may not use this file except in compliance with the License.
- You may obtain a copy of the License at
- http://www.apache.org/licenses/LICENSE-2.0
-
- Authors:
- - Vincent Garonne, <vincent.garonne@cern.ch>, 2014
- - Wen Guan, <wen.guan@cern.ch>, 2015
- - Tomas Javurek, <Tomas.Javurek@cern.ch>, 2016
- - Cedric Serfon, <cedric.serfon@cern.ch>, 2016-2017
- - Mario Lassnig, <mario.lassnig@cern.ch>, 2017
- - Joaquin Bogado, <jbogado@linti.unlp.edu.ar>, 2018
-
- PY3K COMPATIBLE
-'''
+# -*- coding: utf-8 -*-
+# Copyright CERN since 2014
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 from __future__ import print_function
 
