@@ -1,24 +1,38 @@
-# Copyright European Organization for Nuclear Research (CERN)
+# -*- coding: utf-8 -*-
+# Copyright CERN since 2013
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
-# You may not use this file except in compliance with the License.
+# you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-# http://www.apache.org/licenses/LICENSE-2.0
 #
-# Authors:
-# - Vincent Garonne, <vincent.garonne@cern.ch>, 2013
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+"""
+RFIO protocol
+"""
 
 import os
 
 from os.path import dirname
-from urlparse import urlparse
-
+try:
+    # PY2
+    from urlparse import urlparse
+except ImportError:
+    # PY3
+    from urllib.parse import urlparse
 from rucio.common.utils import execute
 from rucio.common import exception
 from rucio.rse.protocols import protocol
 
 
 class Default(protocol.RSEProtocol):
+    """ Implementing access to RSEs using the RFIO protocol. """
 
     def connect(self, credentials):
         """
@@ -62,13 +76,14 @@ class Default(protocol.RSEProtocol):
         if 'STAGE_SVCCLASS' in os.environ:
             del os.environ['STAGE_SVCCLASS']
 
-    def put(self, source, target, source_dir):
+    def put(self, source, target, source_dir, transfer_timeout=None):
         """
             Allows to store files inside the referred RSE.
 
             :param source: path to the source file on the client file system
             :param target: path to the destination file on the storage
             :param source_dir: Path where the to be transferred files are stored in the local file system
+            :param transfer_timeout: Transfer timeout (in seconds) - dummy
 
             :raises DestinationNotAccessible: if the destination storage was not accessible.
             :raises ServiceUnavailable: if some generic error occured in the library.
@@ -82,6 +97,7 @@ class Default(protocol.RSEProtocol):
         return status == 0
 
     def mkdir(self, directory):
+        """ Create new directory. """
         cmd = 'rfmkdir -p %(path)s' % locals()
         status, out, err = execute(cmd)
         return status == 0
