@@ -1,20 +1,17 @@
-'''
- Copyright European Organization for Nuclear Research (CERN)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- You may not use this file except in compliance with the License.
- You may obtain a copy of the License at
- http://www.apache.org/licenses/LICENSE-2.0
-
- Authors:
- - Ralph Vigne, <ralph.vigne@cern.ch>, 2012-2014
- - Mario Lassnig, <mario.lassnig@cern.ch>, 2017
- - Nicolo Magini, <nicolo.magini@cern.ch>, 2018
- - Hannes Hansen, <hannes.jakob.hansen@cern.ch>, 2019
- - Eli Chadwick, <eli.chadwick@stfc.ac.uk>, 2020
-
- PY3K COMPATIBLE
-'''
+# -*- coding: utf-8 -*-
+# Copyright CERN since 2012
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 from six import string_types
 from subprocess import call
