@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2013-2020 CERN
+# Copyright CERN since 2012
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,9 +12,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-#
-# Authors:
-# - Rakshita Varadarajan <rakshitajps@gmail.com>, 2021
 
 import logging
 import os
@@ -96,8 +93,7 @@ class Default(protocol.RSEProtocol):
         self.logger(logging.DEBUG, 'ssh.stat: path: {}'.format(path))
         ret = {}
         chsum = None
-        if path.startswith('scp://'):
-            path = self.pfn2path(path)
+        path = self.pfn2path(path)
 
         try:
             # ssh stat for getting filesize
@@ -310,8 +306,7 @@ class Rsync(Default):
         self.logger(logging.DEBUG, 'rsync.stat: path: {}'.format(path))
         ret = {}
         chsum = None
-        if path.startswith('rsync://'):
-            path = self.pfn2path(path)
+        path = self.pfn2path(path)
 
         try:
             # rsync stat for getting filesize
