@@ -1,4 +1,5 @@
-# Copyright 2019-2020 CERN for the benefit of the ATLAS collaboration.
+# -*- coding: utf-8 -*-
+# Copyright CERN since 2012
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -11,15 +12,8 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-#
-# Authors:
-# - Tomas Javurek <tomas.javurek@cern.ch>, 2019-2020
-# - Boris Bauermeister <boris.bauermeister@fysik.su.se>, 2019
-# - Andrew Lister <andrew.lister@stfc.ac.uk>, 2019
-# - Mario Lassnig <mario.lassnig@cern.ch>, 2019
-# - Eli Chadwick <eli.chadwick@stfc.ac.uk>, 2020
-# - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2020
 
+import logging
 import os
 import requests
 
@@ -173,7 +167,7 @@ class Default(protocol.RSEProtocol):
         # make the symlink
         try:
             os.symlink(target, dest)
-            self.logger.info('StoRM protocol: {}->{}'.format(target, dest))
+            self.logger(logging.INFO, 'StoRM protocol: {}->{}'.format(target, dest))
         except Exception as e:
             exception.ServiceUnavailable('Could not create symlink: %s for target %s' % (str(e), str(target)))
 
