@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2012-2021 CERN
+# Copyright CERN since 2012
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,33 +12,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-#
-# Authors:
-# - Ralph Vigne <ralph.vigne@cern.ch>, 2012-2015
-# - Vincent Garonne <vincent.garonne@cern.ch>, 2012-2018
-# - Mario Lassnig <mario.lassnig@cern.ch>, 2012-2020
-# - Cedric Serfon <cedric.serfon@cern.ch>, 2012-2020
-# - Yun-Pin Sun <winter0128@gmail.com>, 2013
-# - Wen Guan <wen.guan@cern.ch>, 2014-2017
-# - Martin Barisits <martin.barisits@cern.ch>, 2017-2020
-# - Tobias Wegner <twegner@cern.ch>, 2017-2019
-# - Brian Bockelman <bbockelm@cse.unl.edu>, 2018
-# - Frank Berghaus <frank.berghaus@cern.ch>, 2018-2019
-# - Joaquín Bogado <jbogado@linti.unlp.edu.ar>, 2018
-# - Nicolo Magini <nicolo.magini@cern.ch>, 2018
-# - Tomas Javurek <tomas.javurek@cern.ch>, 2018-2020
-# - Hannes Hansen <hannes.jakob.hansen@cern.ch>, 2018-2019
-# - James Perry <j.perry@epcc.ed.ac.uk>, 2019
-# - Andrew Lister <andrew.lister@stfc.ac.uk>, 2019
-# - Gabriele Fronze' <gfronze@cern.ch>, 2019
-# - Jaroslav Guenther <jaroslav.guenther@cern.ch>, 2019-2020
-# - Eli Chadwick <eli.chadwick@stfc.ac.uk>, 2020
-# - Dimitrios Christidis <dimitrios.christidis@cern.ch>, 2020
-# - Patrick Austin <patrick.austin@stfc.ac.uk>, 2020
-# - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2020
-# - Thomas Beermann <thomas.beermann@cern.ch>, 2021
-#
-# PY3K COMPATIBLE
 
 from __future__ import print_function
 
@@ -99,7 +72,7 @@ def get_rse_info(rse=None, vo='def', rse_id=None, session=None):
     return rse_info
 
 
-def _get_possible_protocols(rse_settings, operation, scheme=None, domain=None):
+def _get_possible_protocols(rse_settings, operation, scheme=None, domain=None, impl=None):
     """
     Filter the list of available protocols or provided by the supported ones.
 
@@ -119,6 +92,11 @@ def _get_possible_protocols(rse_settings, operation, scheme=None, domain=None):
 
     tbr = []
     for protocol in candidates:
+        # Check if impl given and filter if so
+        if impl and protocol['impl'] != impl:
+            tbr.append(protocol)
+            continue
+
         # Check if scheme given and filter if so
         if scheme and protocol['scheme'] not in scheme:
             tbr.append(protocol)
@@ -144,14 +122,14 @@ def _get_possible_protocols(rse_settings, operation, scheme=None, domain=None):
     return [c for c in candidates if c not in tbr]
 
 
-def get_protocols_ordered(rse_settings, operation, scheme=None, domain='wan'):
+def get_protocols_ordered(rse_settings, operation, scheme=None, domain='wan', impl=None):
     if operation not in utils.rse_supported_protocol_operations():
         raise exception.RSEOperationNotSupported('Operation %s is not supported' % operation)
 
     if domain and domain not in utils.rse_supported_protocol_domains():
         raise exception.RSEProtocolDomainNotSupported('Domain %s not supported' % domain)
 
-    candidates = _get_possible_protocols(rse_settings, operation, scheme, domain)
+    candidates = _get_possible_protocols(rse_settings, operation, scheme, domain, impl)
     candidates.sort(key=lambda k: k['domains'][domain][operation])
     return candidates
 
@@ -169,7 +147,7 @@ def select_protocol(rse_settings, operation, scheme=None, domain='wan'):
     return min(candidates, key=lambda k: k['domains'][domain][operation])
 
 
-def create_protocol(rse_settings, operation, scheme=None, domain='wan', auth_token=None, logger=logging.log):
+def create_protocol(rse_settings, operation, scheme=None, domain='wan', auth_token=None, protocol_attr=None, logger=logging.log, impl=None):
     """
     Instanciates the protocol defined for the given operation.
 
@@ -178,6 +156,7 @@ def create_protocol(rse_settings, operation, scheme=None, domain='wan', auth_tok
     :param scheme:        Optional filter if no specific protocol is defined in rse_setting for the provided operation
     :param domain:        Optional specification of the domain
     :param auth_token:    Optionally passing JSON Web Token (OIDC) string for authentication
+    :param protocol_attr: Optionally passing the full protocol availability information to correctly select WAN/LAN
     :param logger:        Optional decorated logger that can be passed from the calling daemons or servers.
     :returns:             An instance of the requested protocol
     """
@@ -190,7 +169,17 @@ def create_protocol(rse_settings, operation, scheme=None, domain='wan', auth_tok
     if domain and domain not in utils.rse_supported_protocol_domains():
         raise exception.RSEProtocolDomainNotSupported('Domain %s not supported' % domain)
 
-    protocol_attr = select_protocol(rse_settings, operation, scheme, domain)
+    if impl:
+        candidate = _get_possible_protocols(rse_settings, operation, scheme, domain, impl=impl)
+        if len(candidate) == 0:
+            raise exception.RSEProtocolNotSupported('Protocol implementation %s operation %s on domain %s not supported' % (impl, operation, domain))
+        protocol_attr = candidate[0]
+    elif not protocol_attr:
+        protocol_attr = select_protocol(rse_settings, operation, scheme, domain)
+    else:
+        candidates = _get_possible_protocols(rse_settings, operation, scheme, domain)
+        if protocol_attr not in candidates:
+            raise exception.RSEProtocolNotSupported('Protocol %s operation %s on domain %s not supported' % (protocol_attr, operation, domain))
 
     # Instantiate protocol
     comp = protocol_attr['impl'].split('.')
@@ -208,7 +197,7 @@ def create_protocol(rse_settings, operation, scheme=None, domain='wan', auth_tok
     return protocol
 
 
-def lfns2pfns(rse_settings, lfns, operation='write', scheme=None, domain='wan', auth_token=None, logger=logging.log):
+def lfns2pfns(rse_settings, lfns, operation='write', scheme=None, domain='wan', auth_token=None, logger=logging.log, impl=None):
     """
         Convert the lfn to a pfn
 
@@ -223,7 +212,7 @@ def lfns2pfns(rse_settings, lfns, operation='write', scheme=None, domain='wan',
         :returns:           a dict with scope:name as key and the PFN as value
 
     """
-    return create_protocol(rse_settings, operation, scheme, domain, auth_token=auth_token, logger=logger).lfns2pfns(lfns)
+    return create_protocol(rse_settings, operation, scheme, domain, auth_token=auth_token, logger=logger, impl=impl).lfns2pfns(lfns)
 
 
 def parse_pfns(rse_settings, pfns, operation='read', domain='wan', auth_token=None):
@@ -248,7 +237,7 @@ def parse_pfns(rse_settings, pfns, operation='read', domain='wan', auth_token=No
     return create_protocol(rse_settings, operation, urlparse(pfns[0]).scheme, domain, auth_token=auth_token).parse_pfns(pfns)
 
 
-def exists(rse_settings, files, domain='wan', auth_token=None, logger=logging.log):
+def exists(rse_settings, files, domain='wan', scheme=None, impl=None, auth_token=None, vo='def', logger=logging.log):
     """
         Checks if a file is present at the connected storage.
         Providing a list indicates the bulk mode.
@@ -259,6 +248,7 @@ def exists(rse_settings, files, domain='wan', auth_token=None, logger=logging.lo
                             E.g. {'name': '2_rse_remote_get.raw', 'scope': 'user.jdoe'}, {'name': 'user/jdoe/5a/98/3_rse_remote_get.raw'}
         :param domain:      The network domain, either 'wan' (default) or 'lan'
         :param auth_token:  Optionally passing JSON Web Token (OIDC) string for authentication
+        :param vo:          The VO for the RSE
         :param logger:      Optional decorated logger that can be passed from the calling daemons or servers.
 
         :returns:           True/False for a single file or a dict object with 'scope:name' for LFNs or 'name' for PFNs as keys and True or the exception as value for each file in bulk mode
@@ -269,12 +259,12 @@ def exists(rse_settings, files, domain='wan', auth_token=None, logger=logging.lo
     ret = {}
     gs = True  # gs represents the global status which inidcates if every operation workd in bulk mode
 
-    protocol = create_protocol(rse_settings, 'read', domain=domain, auth_token=auth_token, logger=logger)
+    protocol = create_protocol(rse_settings, 'read', scheme=scheme, impl=impl, domain=domain, auth_token=auth_token, logger=logger)
     protocol.connect()
     try:
         protocol.exists(None)
     except NotImplementedError:
-        protocol = create_protocol(rse_settings, 'write', domain=domain, auth_token=auth_token, logger=logger)
+        protocol = create_protocol(rse_settings, 'write', scheme=scheme, domain=domain, auth_token=auth_token, logger=logger)
         protocol.connect()
     except:
         pass
@@ -292,7 +282,7 @@ def exists(rse_settings, files, domain='wan', auth_token=None, logger=logging.lo
             logger(logging.DEBUG, 'Checking if %s exists', pfn)
             # deal with URL signing if required
             if rse_settings['sign_url'] is not None and pfn[:5] == 'https':
-                pfn = __get_signed_url(rse_settings['rse'], rse_settings['sign_url'], 'read', pfn)    # NOQA pylint: disable=undefined-variable
+                pfn = __get_signed_url(rse_settings['rse'], rse_settings['sign_url'], 'read', pfn, vo)    # NOQA pylint: disable=undefined-variable
             exists = protocol.exists(pfn)
             ret[f['scope'] + ':' + f['name']] = exists
         else:
@@ -308,7 +298,7 @@ def exists(rse_settings, files, domain='wan', auth_token=None, logger=logging.lo
     return [gs, ret]
 
 
-def upload(rse_settings, lfns, domain='wan', source_dir=None, force_pfn=None, force_scheme=None, transfer_timeout=None, delete_existing=False, sign_service=None, auth_token=None, logger=logging.log):
+def upload(rse_settings, lfns, domain='wan', source_dir=None, force_pfn=None, force_scheme=None, transfer_timeout=None, delete_existing=False, sign_service=None, auth_token=None, vo='def', logger=logging.log, impl=None):
     """
         Uploads a file to the connected storage.
         Providing a list indicates the bulk mode.
@@ -328,6 +318,7 @@ def upload(rse_settings, lfns, domain='wan', source_dir=None, force_pfn=None, fo
         :param transfer_timeout:  set this timeout (in seconds) for the transfers, for protocols that support it
         :param sign_service:      use the given service (e.g. gcs, s3, swift) to sign the URL
         :param auth_token:        Optionally passing JSON Web Token (OIDC) string for authentication
+        :param vo:                The VO for the RSE
         :param logger:            Optional decorated logger that can be passed from the calling daemons or servers.
 
         :returns:                 True/False for a single file or a dict object with 'scope:name' as keys and True or the exception as value for each file in bulk mode
@@ -341,17 +332,16 @@ def upload(rse_settings, lfns, domain='wan', source_dir=None, force_pfn=None, fo
     ret = {}
     gs = True  # gs represents the global status which indicates if every operation worked in bulk mode
 
-    protocol = create_protocol(rse_settings, 'write', scheme=force_scheme, domain=domain, auth_token=auth_token, logger=logger)
+    protocol = create_protocol(rse_settings, 'write', scheme=force_scheme, domain=domain, auth_token=auth_token, logger=logger, impl=impl)
     protocol.connect()
-    protocol_delete = create_protocol(rse_settings, 'delete', domain=domain, auth_token=auth_token, logger=logger)
+    protocol_delete = create_protocol(rse_settings, 'delete', domain=domain, auth_token=auth_token, logger=logger, impl=impl)
     protocol_delete.connect()
-
     lfns = [lfns] if not type(lfns) is list else lfns
     for lfn in lfns:
         base_name = lfn.get('filename', lfn['name'])
         name = lfn.get('name', base_name)
         scope = lfn['scope']
-        if 'adler32' not in lfn:
+        if 'adler32' not in lfn and 'md5' not in lfn:
             gs = False
             ret['%s:%s' % (scope, name)] = exception.RucioException('Missing checksum for file %s:%s' % (lfn['scope'], name))
             continue
@@ -359,7 +349,6 @@ def upload(rse_settings, lfns, domain='wan', source_dir=None, force_pfn=None, fo
             gs = False
             ret['%s:%s' % (scope, name)] = exception.RucioException('Missing filesize for file %s:%s' % (lfn['scope'], name))
             continue
-
         if force_pfn:
             pfn = force_pfn
             readpfn = force_pfn
@@ -370,8 +359,8 @@ def upload(rse_settings, lfns, domain='wan', source_dir=None, force_pfn=None, fo
             readpfn = pfn
             if sign_service is not None:
                 # need a separate signed URL for read operations (exists and stat)
-                readpfn = __get_signed_url(rse_settings['rse'], sign_service, 'read', pfn)    # NOQA pylint: disable=undefined-variable
-                pfn = __get_signed_url(rse_settings['rse'], sign_service, 'write', pfn)       # NOQA pylint: disable=undefined-variable
+                readpfn = __get_signed_url(rse_settings['rse'], sign_service, 'read', pfn, vo)    # NOQA pylint: disable=undefined-variable
+                pfn = __get_signed_url(rse_settings['rse'], sign_service, 'write', pfn, vo)       # NOQA pylint: disable=undefined-variable
 
         # First check if renaming operation is supported
         if protocol.renaming:
@@ -508,7 +497,7 @@ def upload(rse_settings, lfns, domain='wan', source_dir=None, force_pfn=None, fo
     return {0: gs, 1: ret, 'success': gs, 'pfn': pfn}
 
 
-def delete(rse_settings, lfns, domain='wan', auth_token=None, logger=logging.log):
+def delete(rse_settings, lfns, domain='wan', auth_token=None, logger=logging.log, impl=None):
     """
         Delete a file from the connected storage.
         Providing a list indicates the bulk mode.
@@ -528,7 +517,7 @@ def delete(rse_settings, lfns, domain='wan', auth_token=None, logger=logging.log
     ret = {}
     gs = True  # gs represents the global status which inidcates if every operation workd in bulk mode
 
-    protocol = create_protocol(rse_settings, 'delete', domain=domain, auth_token=auth_token, logger=logger)
+    protocol = create_protocol(rse_settings, 'delete', domain=domain, auth_token=auth_token, logger=logger, impl=impl)
     protocol.connect()
 
     lfns = [lfns] if not type(lfns) is list else lfns
@@ -551,7 +540,7 @@ def delete(rse_settings, lfns, domain='wan', auth_token=None, logger=logging.log
     return [gs, ret]
 
 
-def rename(rse_settings, files, domain='wan', auth_token=None, logger=logging.log):
+def rename(rse_settings, files, domain='wan', auth_token=None, logger=logging.log, impl=None):
     """
         Rename files stored on the connected storage.
         Providing a list indicates the bulk mode.
@@ -579,7 +568,7 @@ def rename(rse_settings, files, domain='wan', auth_token=None, logger=logging.lo
     ret = {}
     gs = True  # gs represents the global status which inidcates if every operation workd in bulk mode
 
-    protocol = create_protocol(rse_settings, 'write', domain=domain, auth_token=auth_token, logger=logger)
+    protocol = create_protocol(rse_settings, 'write', domain=domain, auth_token=auth_token, logger=logger, impl=impl)
     protocol.connect()
 
     files = [files] if not type(files) is list else files
@@ -627,7 +616,7 @@ def rename(rse_settings, files, domain='wan', auth_token=None, logger=logging.lo
     return [gs, ret]
 
 
-def get_space_usage(rse_settings, scheme=None, domain='wan', auth_token=None, logger=logging.log):
+def get_space_usage(rse_settings, scheme=None, domain='wan', auth_token=None, logger=logging.log, impl=None):
     """
         Get RSE space usage information.
 
@@ -644,7 +633,7 @@ def get_space_usage(rse_settings, scheme=None, domain='wan', auth_token=None, lo
     gs = True
     ret = {}
 
-    protocol = create_protocol(rse_settings, 'read', scheme=scheme, domain=domain, auth_token=auth_token, logger=logger)
+    protocol = create_protocol(rse_settings, 'read', scheme=scheme, domain=domain, auth_token=auth_token, logger=logger, impl=impl)
     protocol.connect()
 
     try:
@@ -736,7 +725,6 @@ def _retry_protocol_stat(protocol, pfn):
     :param pfn          Physical file name of the target for the protocol stat
     """
     retries = config_get_int('client', 'protocol_stat_retries', raise_exception=False, default=6)
-
     for attempt in range(retries):
         try:
             stats = protocol.stat(pfn)
